import React, { Component } from 'react';
import './Todo.css';
import CenteredItemInput from './centered-item-input/CenteredItemInput';
import ItemDisplay from './item-display/ItemDisplay';

// statefull component: will encapsulate the todoItems and perform actions on said state
class Todo extends Component {

  // our todo items represented as a state object with an array of todo items
  state = {
    todoItems: []
  };

  // adds the given todoItem to our list of todo items
  // using arrow function (ES6) allows us to use the 'this' reference for correct scope ie: this object
  addTodoItem = (todoItem) => {
    this.state.todoItems.push(todoItem);

    // this is required when updating any managed state - this way React
    // can be notified when a state change happens and call the render() method
    // of this component.
    this.setState({
      todoItems: this.state.todoItems
    });
  };

  // delete the todo item indexed by the given idx
  // using arrow function (ES6) allows us to use the 'this' reference for correct scope ie: this object
  deleteTodoItem = (idx) => {
    let todoItems = this.state.todoItems;
    todoItems.splice(idx, 1);

    // this is required when updating any managed state - this way React
    // can be notified when a state change happens and call the render() method
    // of this component.
    this.setState({
      todoItems: todoItems
    });
  };

  // called by React to render this part of the DOM, our JSX snippet.
  // pass this.addTodoItem function to CenteredItemInput Component via the addItem attribute
  // pass this.state.todoItems array to the ItemDisplay Component via the items attribute
  // pass this.deleteTodoItem function to the ItemDisplay component via the deleteItem attribute
  render() {
    return (
      <div className="Todo">
        <header className="Todo-header">
          <h1 className="Todo">Todo list</h1>
        </header>
        <CenteredItemInput addItem={this.addTodoItem} />
        <ItemDisplay items={this.state.todoItems} deleteItem={this.deleteTodoItem} />
      </div>
    );
  };
};

// export this class as the default export so that when importing from this file we will by default
// get this class.
export default Todo;