import React, { Component } from 'react';
import './CenteredItemInput.css';

// our text input stateful component
class CenteredItemInput extends Component {

  // the state we are managing
  state = {
    input: ''
  };

  // clears our state / input box by calling the 'setState' method
  // this will indicate to React that the state has changed an trigger a call to render()
  // for this component
  clearInput = () => {
    this.setState({
      input: ''
    });
  };

  // sets our state / input box by calling the 'setState' method
  // the setTodoItemEvent encapsulates an onChange event triggered by key input in our text field
  // this will indicate to React that the state has changed an trigger a call to render()
  // for this component
  setInput = (setTodoItemEvent) => {
    let updated = setTodoItemEvent.target.value;
    this.setState({
      input: updated
    });
  };

  // will take the value in our managed state for this component
  // and call the function on the parent component (Todo) responsile for adding the item
  // clearInput is called to clear the input field once this is done
  addItem = () => {
    if (this.state.input === '') {
      alert('Requires input');
    } else {
      this.props.addItem(this.state.input);
      this.clearInput();
    }
  };

  // this components contribution to the DOM, the JSX snippet
  render() {
    return (
      <div className="Centered-item-input">
        <div className="Centered-item-input-flex-pad" />

        <div className="Centered-item-input-item">
          <form className="form-inline">
            <div className="form-group mx-sm-3 mb-2">
              <input type="text" id="input-desc" className="form-control" size="50" placeholder="Add todo item here" onChange={this.setInput} value={this.state.input} />
            </div>
            <button type="button" onClick={this.addItem} className="btn btn-primary mb-2">Add</button>
          </form>
        </div>

        <div className="Centered-item-input-flex-pad" />
      </div>
    );
  };
}

// export the class CenteredIntemInput as the default export for this class
export default CenteredItemInput;